.. _sim_con:

Simulation Controller module
=============================

Class diagram
-------------------------------

.. graphviz:: ../diagrams/classes_sim_con.dot

See the :ref:`DutView<dut_view>` documentation for available interfaces.

Sequenz for many simulations in parallel
----------------------------------------

.. figure:: ../diagrams/many_simulations.png
   :scale: 100 %
   :alt: Sequenz diagram for SimCon

   This Sequenz diagram shows how to use SimCon to run many simulations in parallel.



Module documentation
------------------------------

.. automodule:: DMT.core.sim_con
    :members:
    :undoc-members:
    :show-inheritance:
